@@ -3,8 +3,10 @@ import logging
 import platform
 import sys
 import traceback
+import typing
 from collections.abc import Callable, Iterable
 from dataclasses import dataclass
+from functools import partial
 from hashlib import sha1
 from typing import Any, Generic, TypeVar
 
@@ -133,3 +135,21 @@ def slugify_with_underscores(s: str) -> str:
 
 def slugify_en_olny(s: str) -> str:
     return slugify(s, regex_pattern=r"[^-a-z0-9]+")
+
+
+# https://youtrack.jetbrains.com/issue/PY-60893/PyCharm-does-not-infer-types-for-zip
+G1 = typing.TypeVar("G1")
+G2 = typing.TypeVar("G2")
+tzip = typing.cast(
+    typing.Callable[[list[G1], ...], list[tuple[G1, ...]]],
+    partial(zip, strict=True),
+)
+tzip_nonstrict = typing.cast(
+    typing.Callable[[list[G1], list[G2]], list[tuple[G1, G2]]],
+    partial(zip, strict=False),
+)
+
+tenumerate = typing.cast(
+    typing.Callable[[Iterable[G1]], Iterable[tuple[int, G1]]],
+    enumerate,
+)
